==> aws-cdk-scala-groundstation_3-0.1.3-javadoc.jar: scripts/searchData.js <==
pages = [{"l":"index.html","n":"groundstation","t":"groundstation","d":"","k":"static"},
{"l":"io/burkard/cdk/services/groundstation.html","n":"io.burkard.cdk.services.groundstation","t":"package io.burkard.cdk.services.groundstation","d":"io/burkard/cdk/services/groundstation","k":"package"},
{"l":"io/burkard/cdk/services/groundstation/AntennaDownlinkConfigProperty$.html","n":"AntennaDownlinkConfigProperty","t":"object AntennaDownlinkConfigProperty","d":"io/burkard/cdk/services/groundstation/AntennaDownlinkConfigProperty$","k":"object"},
{"l":"io/burkard/cdk/services/groundstation/AntennaDownlinkConfigProperty$.html","n":"apply","t":"def apply(spectrumConfig: Option[SpectrumConfigProperty]): AntennaDownlinkConfigProperty","d":"io/burkard/cdk/services/groundstation/AntennaDownlinkConfigProperty$","k":"def"},
{"l":"io/burkard/cdk/services/groundstation/AntennaDownlinkDemodDecodeConfigProperty$.html","n":"AntennaDownlinkDemodDecodeConfigProperty","t":"object AntennaDownlinkDemodDecodeConfigProperty","d":"io/burkard/cdk/services/groundstation/AntennaDownlinkDemodDecodeConfigProperty$","k":"object"},
{"l":"io/burkard/cdk/services/groundstation/AntennaDownlinkDemodDecodeConfigProperty$.html","n":"apply","t":"def apply(spectrumConfig: Option[SpectrumConfigProperty], demodulationConfig: Option[DemodulationConfigProperty], decodeConfig: Option[DecodeConfigProperty]): AntennaDownlinkDemodDecodeConfigProperty","d":"io/burkard/cdk/services/groundstation/AntennaDownlinkDemodDecodeConfigProperty$","k":"def"},
{"l":"io/burkard/cdk/services/groundstation/AntennaUplinkConfigProperty$.html","n":"AntennaUplinkConfigProperty","t":"object AntennaUplinkConfigProperty","d":"io/burkard/cdk/services/groundstation/AntennaUplinkConfigProperty$","k":"object"},
{"l":"io/burkard/cdk/services/groundstation/AntennaUplinkConfigProperty$.html","n":"apply","t":"def apply(spectrumConfig: Option[UplinkSpectrumConfigProperty], targetEirp: Option[EirpProperty], transmitDisabled: Option[Boolean]): AntennaUplinkConfigProperty","d":"io/burkard/cdk/services/groundstation/AntennaUplinkConfigProperty$","k":"def"},
{"l":"io/burkard/cdk/services/groundstation/CfnConfig$.html","n":"CfnConfig","t":"object CfnConfig","d":"io/burkard/cdk/services/groundstation/CfnConfig$","k":"object"},
{"l":"io/burkard/cdk/services/groundstation/CfnConfig$.html","n":"apply","t":"def apply(internalResourceId: String, name: Option[String], tags: Option[List[_ <: CfnTag]], configData: Option[ConfigDataProperty])(implicit stackCtx: Stack): CfnConfig","d":"io/burkard/cdk/services/groundstation/CfnConfig$","k":"def"},
{"l":"io/burkard/cdk/services/groundstation/CfnConfigProps$.html","n":"CfnConfigProps","t":"object CfnConfigProps","d":"io/burkard/cdk/services/groundstation/CfnConfigProps$","k":"object"},
{"l":"io/burkard/cdk/services/groundstation/CfnConfigProps$.html","n":"apply","t":"def apply(name: Option[String], tags: Option[List[_ <: CfnTag]], configData: Option[ConfigDataProperty]): CfnConfigProps","d":"io/burkard/cdk/services/groundstation/CfnConfigProps$","k":"def"},
{"l":"io/burkard/cdk/services/groundstation/CfnDataflowEndpointGroup$.html","n":"CfnDataflowEndpointGroup","t":"object CfnDataflowEndpointGroup","d":"io/burkard/cdk/services/groundstation/CfnDataflowEndpointGroup$","k":"object"},
{"l":"io/burkard/cdk/services/groundstation/CfnDataflowEndpointGroup$.html","n":"apply","t":"def apply(internalResourceId: String, tags: Option[List[_ <: CfnTag]], endpointDetails: Option[List[_]])(implicit stackCtx: Stack): CfnDataflowEndpointGroup","d":"io/burkard/cdk/services/groundstation/CfnDataflowEndpointGroup$","k":"def"},
{"l":"io/burkard/cdk/services/groundstation/CfnDataflowEndpointGroupProps$.html","n":"CfnDataflowEndpointGroupProps","t":"object CfnDataflowEndpointGroupProps","d":"io/burkard/cdk/services/groundstation/CfnDataflowEndpointGroupProps$","k":"object"},
{"l":"io/burkard/cdk/services/groundstation/CfnDataflowEndpointGroupProps$.html","n":"apply","t":"def apply(tags: Option[List[_ <: CfnTag]], endpointDetails: Option[List[_]]): CfnDataflowEndpointGroupProps","d":"io/burkard/cdk/services/groundstation/CfnDataflowEndpointGroupProps$","k":"def"},
{"l":"io/burkard/cdk/services/groundstation/CfnMissionProfile$.html","n":"CfnMissionProfile","t":"object CfnMissionProfile","d":"io/burkard/cdk/services/groundstation/CfnMissionProfile$","k":"object"},
{"l":"io/burkard/cdk/services/groundstation/CfnMissionProfile$.html","n":"apply","t":"def apply(internalResourceId: String, trackingConfigArn: Option[String], dataflowEdges: Option[List[_]], contactPrePassDurationSeconds: Option[Number], name: Option[String], contactPostPassDurationSeconds: Option[Number], minimumViableContactDurationSeconds: Option[Number], tags: Option[List[_ <: CfnTag]])(implicit stackCtx: Stack): CfnMissionProfile","d":"io/burkard/cdk/services/groundstation/CfnMissionProfile$","k":"def"},
{"l":"io/burkard/cdk/services/groundstation/CfnMissionProfileProps$.html","n":"CfnMissionProfileProps","t":"object CfnMissionProfileProps","d":"io/burkard/cdk/services/groundstation/CfnMissionProfileProps$","k":"object"},
{"l":"io/burkard/cdk/services/groundstation/CfnMissionProfileProps$.html","n":"apply","t":"def apply(trackingConfigArn: Option[String], dataflowEdges: Option[List[_]], contactPrePassDurationSeconds: Option[Number], name: Option[String], contactPostPassDurationSeconds: Option[Number], minimumViableContactDurationSeconds: Option[Number], tags: Option[List[_ <: CfnTag]]): CfnMissionProfileProps","d":"io/burkard/cdk/services/groundstation/CfnMissionProfileProps$","k":"def"},
{"l":"io/burkard/cdk/services/groundstation/ConfigDataProperty$.html","n":"ConfigDataProperty","t":"object ConfigDataProperty","d":"io/burkard/cdk/services/groundstation/ConfigDataProperty$","k":"object"},
{"l":"io/burkard/cdk/services/groundstation/ConfigDataProperty$.html","n":"apply","t":"def apply(uplinkEchoConfig: Option[UplinkEchoConfigProperty], antennaDownlinkDemodDecodeConfig: Option[AntennaDownlinkDemodDecodeConfigProperty], dataflowEndpointConfig: Option[DataflowEndpointConfigProperty], antennaDownlinkConfig: Option[AntennaDownlinkConfigProperty], trackingConfig: Option[TrackingConfigProperty], s3RecordingConfig: Option[S3RecordingConfigProperty], antennaUplinkConfig: Option[AntennaUplinkConfigProperty]): ConfigDataProperty","d":"io/burkard/cdk/services/groundstation/ConfigDataProperty$","k":"def"},
{"l":"io/burkard/cdk/services/groundstation/DataflowEdgeProperty$.html","n":"DataflowEdgeProperty","t":"object DataflowEdgeProperty","d":"io/burkard/cdk/services/groundstation/DataflowEdgeProperty$","k":"object"},
{"l":"io/burkard/cdk/services/groundstation/DataflowEdgeProperty$.html","n":"apply","t":"def apply(source: Option[String], destination: Option[String]): DataflowEdgeProperty","d":"io/burkard/cdk/services/groundstation/DataflowEdgeProperty$","k":"def"},
{"l":"io/burkard/cdk/services/groundstation/DataflowEndpointConfigProperty$.html","n":"DataflowEndpointConfigProperty","t":"object DataflowEndpointConfigProperty","d":"io/burkard/cdk/services/groundstation/DataflowEndpointConfigProperty$","k":"object"},
{"l":"io/burkard/cdk/services/groundstation/DataflowEndpointConfigProperty$.html","n":"apply","t":"def apply(dataflowEndpointName: Option[String], dataflowEndpointRegion: Option[String]): DataflowEndpointConfigProperty","d":"io/burkard/cdk/services/groundstation/DataflowEndpointConfigProperty$","k":"def"},
{"l":"io/burkard/cdk/services/groundstation/DataflowEndpointProperty$.html","n":"DataflowEndpointProperty","t":"object DataflowEndpointProperty","d":"io/burkard/cdk/services/groundstation/DataflowEndpointProperty$","k":"object"},
{"l":"io/burkard/cdk/services/groundstation/DataflowEndpointProperty$.html","n":"apply","t":"def apply(name: Option[String], mtu: Option[Number], address: Option[SocketAddressProperty]): DataflowEndpointProperty","d":"io/burkard/cdk/services/groundstation/DataflowEndpointProperty$","k":"def"},
{"l":"io/burkard/cdk/services/groundstation/DecodeConfigProperty$.html","n":"DecodeConfigProperty","t":"object DecodeConfigProperty","d":"io/burkard/cdk/services/groundstation/DecodeConfigProperty$","k":"object"},
{"l":"io/burkard/cdk/services/groundstation/DecodeConfigProperty$.html","n":"apply","t":"def apply(unvalidatedJson: Option[String]): DecodeConfigProperty","d":"io/burkard/cdk/services/groundstation/DecodeConfigProperty$","k":"def"},
{"l":"io/burkard/cdk/services/groundstation/DemodulationConfigProperty$.html","n":"DemodulationConfigProperty","t":"object DemodulationConfigProperty","d":"io/burkard/cdk/services/groundstation/DemodulationConfigProperty$","k":"object"},
{"l":"io/burkard/cdk/services/groundstation/DemodulationConfigProperty$.html","n":"apply","t":"def apply(unvalidatedJson: Option[String]): DemodulationConfigProperty","d":"io/burkard/cdk/services/groundstation/DemodulationConfigProperty$","k":"def"},
{"l":"io/burkard/cdk/services/groundstation/EirpProperty$.html","n":"EirpProperty","t":"object EirpProperty","d":"io/burkard/cdk/services/groundstation/EirpProperty$","k":"object"},
{"l":"io/burkard/cdk/services/groundstation/EirpProperty$.html","n":"apply","t":"def apply(units: Option[String], value: Option[Number]): EirpProperty","d":"io/burkard/cdk/services/groundstation/EirpProperty$","k":"def"},
{"l":"io/burkard/cdk/services/groundstation/EndpointDetailsProperty$.html","n":"EndpointDetailsProperty","t":"object EndpointDetailsProperty","d":"io/burkard/cdk/services/groundstation/EndpointDetailsProperty$","k":"object"},
{"l":"io/burkard/cdk/services/groundstation/EndpointDetailsProperty$.html","n":"apply","t":"def apply(securityDetails: Option[SecurityDetailsProperty], endpoint: Option[DataflowEndpointProperty]): EndpointDetailsProperty","d":"io/burkard/cdk/services/groundstation/EndpointDetailsProperty$","k":"def"},
{"l":"io/burkard/cdk/services/groundstation/FrequencyBandwidthProperty$.html","n":"FrequencyBandwidthProperty","t":"object FrequencyBandwidthProperty","d":"io/burkard/cdk/services/groundstation/FrequencyBandwidthProperty$","k":"object"},
{"l":"io/burkard/cdk/services/groundstation/FrequencyBandwidthProperty$.html","n":"apply","t":"def apply(units: Option[String], value: Option[Number]): FrequencyBandwidthProperty","d":"io/burkard/cdk/services/groundstation/FrequencyBandwidthProperty$","k":"def"},
{"l":"io/burkard/cdk/services/groundstation/FrequencyProperty$.html","n":"FrequencyProperty","t":"object FrequencyProperty","d":"io/burkard/cdk/services/groundstation/FrequencyProperty$","k":"object"},
{"l":"io/burkard/cdk/services/groundstation/FrequencyProperty$.html","n":"apply","t":"def apply(units: Option[String], value: Option[Number]): FrequencyProperty","d":"io/burkard/cdk/services/groundstation/FrequencyProperty$","k":"def"},
{"l":"io/burkard/cdk/services/groundstation/S3RecordingConfigProperty$.html","n":"S3RecordingConfigProperty","t":"object S3RecordingConfigProperty","d":"io/burkard/cdk/services/groundstation/S3RecordingConfigProperty$","k":"object"},
{"l":"io/burkard/cdk/services/groundstation/S3RecordingConfigProperty$.html","n":"apply","t":"def apply(prefix: Option[String], roleArn: Option[String], bucketArn: Option[String]): S3RecordingConfigProperty","d":"io/burkard/cdk/services/groundstation/S3RecordingConfigProperty$","k":"def"},
{"l":"io/burkard/cdk/services/groundstation/SecurityDetailsProperty$.html","n":"SecurityDetailsProperty","t":"object SecurityDetailsProperty","d":"io/burkard/cdk/services/groundstation/SecurityDetailsProperty$","k":"object"},
{"l":"io/burkard/cdk/services/groundstation/SecurityDetailsProperty$.html","n":"apply","t":"def apply(subnetIds: Option[List[String]], securityGroupIds: Option[List[String]], roleArn: Option[String]): SecurityDetailsProperty","d":"io/burkard/cdk/services/groundstation/SecurityDetailsProperty$","k":"def"},
{"l":"io/burkard/cdk/services/groundstation/SocketAddressProperty$.html","n":"SocketAddressProperty","t":"object SocketAddressProperty","d":"io/burkard/cdk/services/groundstation/SocketAddressProperty$","k":"object"},
{"l":"io/burkard/cdk/services/groundstation/SocketAddressProperty$.html","n":"apply","t":"def apply(name: Option[String], port: Option[Number]): SocketAddressProperty","d":"io/burkard/cdk/services/groundstation/SocketAddressProperty$","k":"def"},
{"l":"io/burkard/cdk/services/groundstation/SpectrumConfigProperty$.html","n":"SpectrumConfigProperty","t":"object SpectrumConfigProperty","d":"io/burkard/cdk/services/groundstation/SpectrumConfigProperty$","k":"object"},
{"l":"io/burkard/cdk/services/groundstation/SpectrumConfigProperty$.html","n":"apply","t":"def apply(polarization: Option[String], bandwidth: Option[FrequencyBandwidthProperty], centerFrequency: Option[FrequencyProperty]): SpectrumConfigProperty","d":"io/burkard/cdk/services/groundstation/SpectrumConfigProperty$","k":"def"},
{"l":"io/burkard/cdk/services/groundstation/TrackingConfigProperty$.html","n":"TrackingConfigProperty","t":"object TrackingConfigProperty","d":"io/burkard/cdk/services/groundstation/TrackingConfigProperty$","k":"object"},
{"l":"io/burkard/cdk/services/groundstation/TrackingConfigProperty$.html","n":"apply","t":"def apply(autotrack: Option[String]): TrackingConfigProperty","d":"io/burkard/cdk/services/groundstation/TrackingConfigProperty$","k":"def"},
{"l":"io/burkard/cdk/services/groundstation/UplinkEchoConfigProperty$.html","n":"UplinkEchoConfigProperty","t":"object UplinkEchoConfigProperty","d":"io/burkard/cdk/services/groundstation/UplinkEchoConfigProperty$","k":"object"},
{"l":"io/burkard/cdk/services/groundstation/UplinkEchoConfigProperty$.html","n":"apply","t":"def apply(antennaUplinkConfigArn: Option[String], enabled: Option[Boolean]): UplinkEchoConfigProperty","d":"io/burkard/cdk/services/groundstation/UplinkEchoConfigProperty$","k":"def"},
{"l":"io/burkard/cdk/services/groundstation/UplinkSpectrumConfigProperty$.html","n":"UplinkSpectrumConfigProperty","t":"object UplinkSpectrumConfigProperty","d":"io/burkard/cdk/services/groundstation/UplinkSpectrumConfigProperty$","k":"object"},
{"l":"io/burkard/cdk/services/groundstation/UplinkSpectrumConfigProperty$.html","n":"apply","t":"def apply(polarization: Option[String], centerFrequency: Option[FrequencyProperty]): UplinkSpectrumConfigProperty","d":"io/burkard/cdk/services/groundstation/UplinkSpectrumConfigProperty$","k":"def"},
{"l":"docs/index.html","n":"groundstation","t":"groundstation","d":"","k":"static"}];

==> aws-cdk-scala-groundstation_3-0.2.0-javadoc.jar: scripts/searchData.js <==
pages = [{"l":"index.html","n":"groundstation","t":"groundstation","d":"","k":"static"},
{"l":"io/burkard/cdk/services/groundstation.html","n":"io.burkard.cdk.services.groundstation","t":"package io.burkard.cdk.services.groundstation","d":"io/burkard/cdk/services/groundstation","k":"package"},
{"l":"io/burkard/cdk/services/groundstation/AntennaDownlinkConfigProperty$.html","n":"AntennaDownlinkConfigProperty","t":"object AntennaDownlinkConfigProperty","d":"io/burkard/cdk/services/groundstation/AntennaDownlinkConfigProperty$","k":"object"},
{"l":"io/burkard/cdk/services/groundstation/AntennaDownlinkConfigProperty$.html","n":"apply","t":"def apply(spectrumConfig: Option[SpectrumConfigProperty]): AntennaDownlinkConfigProperty","d":"io/burkard/cdk/services/groundstation/AntennaDownlinkConfigProperty$","k":"def"},
{"l":"io/burkard/cdk/services/groundstation/AntennaDownlinkDemodDecodeConfigProperty$.html","n":"AntennaDownlinkDemodDecodeConfigProperty","t":"object AntennaDownlinkDemodDecodeConfigProperty","d":"io/burkard/cdk/services/groundstation/AntennaDownlinkDemodDecodeConfigProperty$","k":"object"},
{"l":"io/burkard/cdk/services/groundstation/AntennaDownlinkDemodDecodeConfigProperty$.html","n":"apply","t":"def apply(spectrumConfig: Option[SpectrumConfigProperty], demodulationConfig: Option[DemodulationConfigProperty], decodeConfig: Option[DecodeConfigProperty]): AntennaDownlinkDemodDecodeConfigProperty","d":"io/burkard/cdk/services/groundstation/AntennaDownlinkDemodDecodeConfigProperty$","k":"def"},
{"l":"io/burkard/cdk/services/groundstation/AntennaUplinkConfigProperty$.html","n":"AntennaUplinkConfigProperty","t":"object AntennaUplinkConfigProperty","d":"io/burkard/cdk/services/groundstation/AntennaUplinkConfigProperty$","k":"object"},
{"l":"io/burkard/cdk/services/groundstation/AntennaUplinkConfigProperty$.html","n":"apply","t":"def apply(spectrumConfig: Option[UplinkSpectrumConfigProperty], targetEirp: Option[EirpProperty], transmitDisabled: Option[Boolean]): AntennaUplinkConfigProperty","d":"io/burkard/cdk/services/groundstation/AntennaUplinkConfigProperty$","k":"def"},
{"l":"io/burkard/cdk/services/groundstation/CfnConfig$.html","n":"CfnConfig","t":"object CfnConfig","d":"io/burkard/cdk/services/groundstation/CfnConfig$","k":"object"},
{"l":"io/burkard/cdk/services/groundstation/CfnConfig$.html","n":"apply","t":"def apply(internalResourceId: String, name: String, configData: ConfigDataProperty, tags: Option[List[_ <: CfnTag]])(implicit stackCtx: Stack): CfnConfig","d":"io/burkard/cdk/services/groundstation/CfnConfig$","k":"def"},
{"l":"io/burkard/cdk/services/groundstation/CfnConfigProps$.html","n":"CfnConfigProps","t":"object CfnConfigProps","d":"io/burkard/cdk/services/groundstation/CfnConfigProps$","k":"object"},
{"l":"io/burkard/cdk/services/groundstation/CfnConfigProps$.html","n":"apply","t":"def apply(name: String, configData: ConfigDataProperty, tags: Option[List[_ <: CfnTag]]): CfnConfigProps","d":"io/burkard/cdk/services/groundstation/CfnConfigProps$","k":"def"},
{"l":"io/burkard/cdk/services/groundstation/CfnDataflowEndpointGroup$.html","n":"CfnDataflowEndpointGroup","t":"object CfnDataflowEndpointGroup","d":"io/burkard/cdk/services/groundstation/CfnDataflowEndpointGroup$","k":"object"},
{"l":"io/burkard/cdk/services/groundstation/CfnDataflowEndpointGroup$.html","n":"apply","t":"def apply(internalResourceId: String, endpointDetails: List[_], tags: Option[List[_ <: CfnTag]])(implicit stackCtx: Stack): CfnDataflowEndpointGroup","d":"io/burkard/cdk/services/groundstation/CfnDataflowEndpointGroup$","k":"def"},
{"l":"io/burkard/cdk/services/groundstation/CfnDataflowEndpointGroupProps$.html","n":"CfnDataflowEndpointGroupProps","t":"object CfnDataflowEndpointGroupProps","d":"io/burkard/cdk/services/groundstation/CfnDataflowEndpointGroupProps$","k":"object"},
{"l":"io/burkard/cdk/services/groundstation/CfnDataflowEndpointGroupProps$.html","n":"apply","t":"def apply(endpointDetails: List[_], tags: Option[List[_ <: CfnTag]]): CfnDataflowEndpointGroupProps","d":"io/burkard/cdk/services/groundstation/CfnDataflowEndpointGroupProps$","k":"def"},
{"l":"io/burkard/cdk/services/groundstation/CfnMissionProfile$.html","n":"CfnMissionProfile","t":"object CfnMissionProfile","d":"io/burkard/cdk/services/groundstation/CfnMissionProfile$","k":"object"},
{"l":"io/burkard/cdk/services/groundstation/CfnMissionProfile$.html","n":"apply","t":"def apply(internalResourceId: String, trackingConfigArn: String, dataflowEdges: List[_], name: String, minimumViableContactDurationSeconds: Number, contactPrePassDurationSeconds: Option[Number], contactPostPassDurationSeconds: Option[Number], tags: Option[List[_ <: CfnTag]])(implicit stackCtx: Stack): CfnMissionProfile","d":"io/burkard/cdk/services/groundstation/CfnMissionProfile$","k":"def"},
{"l":"io/burkard/cdk/services/groundstation/CfnMissionProfileProps$.html","n":"CfnMissionProfileProps","t":"object CfnMissionProfileProps","d":"io/burkard/cdk/services/groundstation/CfnMissionProfileProps$","k":"object"},
{"l":"io/burkard/cdk/services/groundstation/CfnMissionProfileProps$.html","n":"apply","t":"def apply(trackingConfigArn: String, dataflowEdges: List[_], name: String, minimumViableContactDurationSeconds: Number, contactPrePassDurationSeconds: Option[Number], contactPostPassDurationSeconds: Option[Number], tags: Option[List[_ <: CfnTag]]): CfnMissionProfileProps","d":"io/burkard/cdk/services/groundstation/CfnMissionProfileProps$","k":"def"},
{"l":"io/burkard/cdk/services/groundstation/ConfigDataProperty$.html","n":"ConfigDataProperty","t":"object ConfigDataProperty","d":"io/burkard/cdk/services/groundstation/ConfigDataProperty$","k":"object"},
{"l":"io/burkard/cdk/services/groundstation/ConfigDataProperty$.html","n":"apply","t":"def apply(uplinkEchoConfig: Option[UplinkEchoConfigProperty], antennaDownlinkDemodDecodeConfig: Option[AntennaDownlinkDemodDecodeConfigProperty], dataflowEndpointConfig: Option[DataflowEndpointConfigProperty], antennaDownlinkConfig: Option[AntennaDownlinkConfigProperty], trackingConfig: Option[TrackingConfigProperty], s3RecordingConfig: Option[S3RecordingConfigProperty], antennaUplinkConfig: Option[AntennaUplinkConfigProperty]): ConfigDataProperty","d":"io/burkard/cdk/services/groundstation/ConfigDataProperty$","k":"def"},
{"l":"io/burkard/cdk/services/groundstation/DataflowEdgeProperty$.html","n":"DataflowEdgeProperty","t":"object DataflowEdgeProperty","d":"io/burkard/cdk/services/groundstation/DataflowEdgeProperty$","k":"object"},
{"l":"io/burkard/cdk/services/groundstation/DataflowEdgeProperty$.html","n":"apply","t":"def apply(source: Option[String], destination: Option[String]): DataflowEdgeProperty","d":"io/burkard/cdk/services/groundstation/DataflowEdgeProperty$","k":"def"},
{"l":"io/burkard/cdk/services/groundstation/DataflowEndpointConfigProperty$.html","n":"DataflowEndpointConfigProperty","t":"object DataflowEndpointConfigProperty","d":"io/burkard/cdk/services/groundstation/DataflowEndpointConfigProperty$","k":"object"},
{"l":"io/burkard/cdk/services/groundstation/DataflowEndpointConfigProperty$.html","n":"apply","t":"def apply(dataflowEndpointName: Option[String], dataflowEndpointRegion: Option[String]): DataflowEndpointConfigProperty","d":"io/burkard/cdk/services/groundstation/DataflowEndpointConfigProperty$","k":"def"},
{"l":"io/burkard/cdk/services/groundstation/DataflowEndpointProperty$.html","n":"DataflowEndpointProperty","t":"object DataflowEndpointProperty","d":"io/burkard/cdk/services/groundstation/DataflowEndpointProperty$","k":"object"},
{"l":"io/burkard/cdk/services/groundstation/DataflowEndpointProperty$.html","n":"apply","t":"def apply(name: Option[String], mtu: Option[Number], address: Option[SocketAddressProperty]): DataflowEndpointProperty","d":"io/burkard/cdk/services/groundstation/DataflowEndpointProperty$","k":"def"},
{"l":"io/burkard/cdk/services/groundstation/DecodeConfigProperty$.html","n":"DecodeConfigProperty","t":"object DecodeConfigProperty","d":"io/burkard/cdk/services/groundstation/DecodeConfigProperty$","k":"object"},
{"l":"io/burkard/cdk/services/groundstation/DecodeConfigProperty$.html","n":"apply","t":"def apply(unvalidatedJson: Option[String]): DecodeConfigProperty","d":"io/burkard/cdk/services/groundstation/DecodeConfigProperty$","k":"def"},
{"l":"io/burkard/cdk/services/groundstation/DemodulationConfigProperty$.html","n":"DemodulationConfigProperty","t":"object DemodulationConfigProperty","d":"io/burkard/cdk/services/groundstation/DemodulationConfigProperty$","k":"object"},
{"l":"io/burkard/cdk/services/groundstation/DemodulationConfigProperty$.html","n":"apply","t":"def apply(unvalidatedJson: Option[String]): DemodulationConfigProperty","d":"io/burkard/cdk/services/groundstation/DemodulationConfigProperty$","k":"def"},
{"l":"io/burkard/cdk/services/groundstation/EirpProperty$.html","n":"EirpProperty","t":"object EirpProperty","d":"io/burkard/cdk/services/groundstation/EirpProperty$","k":"object"},
{"l":"io/burkard/cdk/services/groundstation/EirpProperty$.html","n":"apply","t":"def apply(units: Option[String], value: Option[Number]): EirpProperty","d":"io/burkard/cdk/services/groundstation/EirpProperty$","k":"def"},
{"l":"io/burkard/cdk/services/groundstation/EndpointDetailsProperty$.html","n":"EndpointDetailsProperty","t":"object EndpointDetailsProperty","d":"io/burkard/cdk/services/groundstation/EndpointDetailsProperty$","k":"object"},
{"l":"io/burkard/cdk/services/groundstation/EndpointDetailsProperty$.html","n":"apply","t":"def apply(securityDetails: Option[SecurityDetailsProperty], endpoint: Option[DataflowEndpointProperty]): EndpointDetailsProperty","d":"io/burkard/cdk/services/groundstation/EndpointDetailsProperty$","k":"def"},
{"l":"io/burkard/cdk/services/groundstation/FrequencyBandwidthProperty$.html","n":"FrequencyBandwidthProperty","t":"object FrequencyBandwidthProperty","d":"io/burkard/cdk/services/groundstation/FrequencyBandwidthProperty$","k":"object"},
{"l":"io/burkard/cdk/services/groundstation/FrequencyBandwidthProperty$.html","n":"apply","t":"def apply(units: Option[String], value: Option[Number]): FrequencyBandwidthProperty","d":"io/burkard/cdk/services/groundstation/FrequencyBandwidthProperty$","k":"def"},
{"l":"io/burkard/cdk/services/groundstation/FrequencyProperty$.html","n":"FrequencyProperty","t":"object FrequencyProperty","d":"io/burkard/cdk/services/groundstation/FrequencyProperty$","k":"object"},
{"l":"io/burkard/cdk/services/groundstation/FrequencyProperty$.html","n":"apply","t":"def apply(units: Option[String], value: Option[Number]): FrequencyProperty","d":"io/burkard/cdk/services/groundstation/FrequencyProperty$","k":"def"},
{"l":"io/burkard/cdk/services/groundstation/S3RecordingConfigProperty$.html","n":"S3RecordingConfigProperty","t":"object S3RecordingConfigProperty","d":"io/burkard/cdk/services/groundstation/S3RecordingConfigProperty$","k":"object"},
{"l":"io/burkard/cdk/services/groundstation/S3RecordingConfigProperty$.html","n":"apply","t":"def apply(prefix: Option[String], roleArn: Option[String], bucketArn: Option[String]): S3RecordingConfigProperty","d":"io/burkard/cdk/services/groundstation/S3RecordingConfigProperty$","k":"def"},
{"l":"io/burkard/cdk/services/groundstation/SecurityDetailsProperty$.html","n":"SecurityDetailsProperty","t":"object SecurityDetailsProperty","d":"io/burkard/cdk/services/groundstation/SecurityDetailsProperty$","k":"object"},
{"l":"io/burkard/cdk/services/groundstation/SecurityDetailsProperty$.html","n":"apply","t":"def apply(subnetIds: Option[List[String]], securityGroupIds: Option[List[String]], roleArn: Option[String]): SecurityDetailsProperty","d":"io/burkard/cdk/services/groundstation/SecurityDetailsProperty$","k":"def"},
{"l":"io/burkard/cdk/services/groundstation/SocketAddressProperty$.html","n":"SocketAddressProperty","t":"object SocketAddressProperty","d":"io/burkard/cdk/services/groundstation/SocketAddressProperty$","k":"object"},
{"l":"io/burkard/cdk/services/groundstation/SocketAddressProperty$.html","n":"apply","t":"def apply(name: Option[String], port: Option[Number]): SocketAddressProperty","d":"io/burkard/cdk/services/groundstation/SocketAddressProperty$","k":"def"},
{"l":"io/burkard/cdk/services/groundstation/SpectrumConfigProperty$.html","n":"SpectrumConfigProperty","t":"object SpectrumConfigProperty","d":"io/burkard/cdk/services/groundstation/SpectrumConfigProperty$","k":"object"},
{"l":"io/burkard/cdk/services/groundstation/SpectrumConfigProperty$.html","n":"apply","t":"def apply(polarization: Option[String], bandwidth: Option[FrequencyBandwidthProperty], centerFrequency: Option[FrequencyProperty]): SpectrumConfigProperty","d":"io/burkard/cdk/services/groundstation/SpectrumConfigProperty$","k":"def"},
{"l":"io/burkard/cdk/services/groundstation/TrackingConfigProperty$.html","n":"TrackingConfigProperty","t":"object TrackingConfigProperty","d":"io/burkard/cdk/services/groundstation/TrackingConfigProperty$","k":"object"},
{"l":"io/burkard/cdk/services/groundstation/TrackingConfigProperty$.html","n":"apply","t":"def apply(autotrack: Option[String]): TrackingConfigProperty","d":"io/burkard/cdk/services/groundstation/TrackingConfigProperty$","k":"def"},
{"l":"io/burkard/cdk/services/groundstation/UplinkEchoConfigProperty$.html","n":"UplinkEchoConfigProperty","t":"object UplinkEchoConfigProperty","d":"io/burkard/cdk/services/groundstation/UplinkEchoConfigProperty$","k":"object"},
{"l":"io/burkard/cdk/services/groundstation/UplinkEchoConfigProperty$.html","n":"apply","t":"def apply(antennaUplinkConfigArn: Option[String], enabled: Option[Boolean]): UplinkEchoConfigProperty","d":"io/burkard/cdk/services/groundstation/UplinkEchoConfigProperty$","k":"def"},
{"l":"io/burkard/cdk/services/groundstation/UplinkSpectrumConfigProperty$.html","n":"UplinkSpectrumConfigProperty","t":"object UplinkSpectrumConfigProperty","d":"io/burkard/cdk/services/groundstation/UplinkSpectrumConfigProperty$","k":"object"},
{"l":"io/burkard/cdk/services/groundstation/UplinkSpectrumConfigProperty$.html","n":"apply","t":"def apply(polarization: Option[String], centerFrequency: Option[FrequencyProperty]): UplinkSpectrumConfigProperty","d":"io/burkard/cdk/services/groundstation/UplinkSpectrumConfigProperty$","k":"def"},
{"l":"docs/index.html","n":"groundstation","t":"groundstation","d":"","k":"static"}];
